@@ -82,7 +82,7 @@ Laplace$set("public", "pgf", function(z){
 Laplace$set("public", "cf", function(t){
   return(exp(self$getParameterValue("mean") * t * 1i) / (1 + self$getParameterValue("scale")^2 * t^2))
 })
-Laplace$set("public","mode",function(){
+Laplace$set("public","mode",function(which = NULL){
   return(self$getParameterValue("mean"))
 })
 
